@@ -10,7 +10,9 @@ use Zim::Components::TreeView;
 use Zim::Components::PathBar;
 use Zim::Components::PageView;
 
-our $VERSION = 0.07;
+# TODO make components configable/autoloading like plugins
+
+our $VERSION = 0.08;
 our $LONG_VERSION = << "EOT";
 zim $VERSION
 
@@ -85,6 +87,8 @@ our %CONFIG = (  # Default config values
 	undo_max	=> 50,
 	follow_new_link => 1,
 	use_xdg_cache	=> 0,
+	use_tray_icon	=> 0,
+	backsp_unindent => 1,
 );
 
 =item C<new(SETTINGS)>
@@ -144,7 +148,7 @@ sub gui_init {
 
 	my $window = Gtk2::Window->new('toplevel');
 	$window->set_default_size(@{$self->{settings}}{'width', 'height'});
-	$window->signal_connect(delete_event => \&on_delete_event, $self);
+	$window->signal_connect_swapped(delete_event => \&on_delete_event, $self);
 	$window->signal_connect(destroy => sub { Gtk2->main_quit });
 	$window->set_icon(
 		Gtk2::Gdk::Pixbuf->new_from_file($self->{settings}{icon_file}) );
@@ -225,8 +229,8 @@ sub gui_init {
 
 	$toolbar->append_space;
 
-	#my $actions_button = add_button(
-	#	'Actions', '', 'gtk-execute', sub {});
+	$self->add_button('Actions', '', 'gtk-execute',
+		sub {$self->filechooser_dialog} );
 	$self->add_button('About', 'F1', 'gtk-help',
 		sub {$self->about_dialog} );
 
@@ -236,13 +240,19 @@ sub gui_init {
 
 	$self->add_key('Ctrl G', sub {$self->goto_page_dialog});
 	$self->add_key('Ctrl R', sub {$self->reload});
+	$self->add_key('Ctrl Q', sub {$self->quit('FORCE')});
 	$self->add_key('Ctrl W', sub {$self->quit});
-	$self->add_key('Alt Up', sub { 
+	$self->add_key('Alt Up', sub {
 		my $namespace = $self->{page}->namespace;
-		$namespace = $self->{settings}{home} if $namespace eq ':';
-		$namespace =~ s/^:?/:/;
+		return if $namespace eq ':';
 		$self->load_page($namespace);
 	} );
+	$self->add_key('Alt Down', sub {
+		my $namespace = $self->History->get_namespace;
+		my $name = $self->{page}->name;
+		return unless $namespace =~ /^(:*$name:+[^:]+)/;
+		$self->load_page($1);
+	} );
 	$self->add_key('Alt D', sub {
 		my $page = strftime($self->{settings}{date_page}, localtime);
 		$self->load_page($page);
@@ -268,7 +278,34 @@ sub gui_init {
 		unless $self->{settings}{read_only};
 	
 	$window->show_all;
-	$page_view->hide_search;
+
+	if ($self->{settings}{use_tray_icon}) {
+		eval {
+			eval 'use Zim::Components::TrayIcon'; die $@ if $@;
+			my $trayicon = Zim::Components::TrayIcon->new(app => $self);
+		} ;
+		warn $@ if $@;
+	}
+
+#	unless ($self->{settings}{read_only}) {
+		# FIXME this is a ugly and quick hack
+		# FIXME should this be in the repository api ??
+#		my $root = $self->{repository}{root};
+#		my $lock_file = File::Spec->catfile($root, '.zim.pid');
+#		exit 1 if -e $lock_file and
+#			! $self->repository_lock_dialog($root);
+#		open LOCK, ">$lock_file" or $self->exit_error(
+#			"Could not write lock file:\n$lock_file" );
+#		print LOCK "$$\n";
+#		close LOCK;
+#		$self->{lock_file} = $lock_file;
+#	}
+	
+	# Try saving when the user exits shell or desktop
+	$SIG{$_} = sub {
+		$self->quit('FORCE');
+		exit 1;
+	} for qw/INT TERM HUP/;
 }
 
 =item C<widget()>
@@ -351,7 +388,6 @@ sub save_config {
 		for sort keys %CONFIG; # we do not save all settings
 	close CONF;
 	#print "saved config to $file\n";
-
 }
 
 sub _mkdir {
@@ -378,10 +414,14 @@ This method runs the GUI application.
 sub main_loop {
 	my $self = shift;
 	
-	unless ($self->{page}) { # FIXME what if we are read_only and page does not exist ?
+	unless ($self->{page}) {
 		my $page = $self->{objects}{History}->get_current
 			|| $self->{settings}{home};
 		$self->load_page($page);
+		# FIXME what if we are read_only and page does not exist ?
+		# 	load_apge returns undef
+		# 	first try home, but might also not exist
+		# 	need page that always exists ... like about or version page
 	}
 	
 	$self->{message_lock} = 1;
@@ -402,14 +442,27 @@ Exit the main loop.
 
 sub quit {
 	my $self = shift;
-	&on_delete_event($self->{window}, $self) && return;
+	return if $$self{_saved_state};
+	$$self{_saved_state} = 1;
+	$self->on_delete_event(@_) && return;
 	Gtk2->main_quit;
 }
 
-sub on_delete_event { # Called when the window is deleted
-	my $self = pop;
-	my $window = shift;
-	@{$self->{settings}}{'width', 'height'} = $window->get_size;
+sub on_delete_event {
+	# Called when the window is deleted
+	# return true to avoid destruction
+	my $self = shift;
+	my $force = uc(shift) eq 'FORCE';
+
+	if ($self->{settings}{hide_on_delete} and !$force) {
+		$self->{window}->hide;
+		return 1;
+	}
+	
+	#print STDERR "Zim saving state\n";
+	
+	eval {	@{$self->{settings}}{'width', 'height'} =
+			$self->{window}->get_size          };
 	
 	$self->{save_lock} = 0; # just to be sure
 	$self->save_page() || return 1;
@@ -421,7 +474,12 @@ sub on_delete_event { # Called when the window is deleted
 		$self->{objects}{History}->write;
 	}
 
-	return 0; # let window continu with destruction
+	if ($self->{lock_file}) {
+		unlink $self->{lock_file}
+			or warn "Could not remove $self->{lock_file}\n";
+	}
+
+	return 0;
 }
 
 =item C<link_clicked(LINK)>
@@ -440,11 +498,12 @@ sub link_clicked {
 
 	if ($link =~ /^(\w+:\/\/|mailto:)/) { # link is an url
 		my $browser = $self->{settings}{browser} || $ENV{BROWSER};
-		return error_dialog(
-			"You have no browser configured.".
-			"Try setting the \$BROWSER environment variable".
-			"or edit the zim config file."
-		) unless $browser;
+		unless ($browser) {
+			$browser = $self->prompt_browser_dialog;
+			return $self->error_dialog('You have no browser configured')
+				unless $browser;
+			$self->{settings}{browser} = $browser;
+		}
 		$browser =~ s/\%s/$link/ or $browser .= ' '.$link;
 		unless (fork) { # child process
 			exec $browser;
@@ -452,8 +511,8 @@ sub link_clicked {
 		}
 	}
 	else {
-		$link = $self->{page}->resolve_link($link);
-		$self->load_page($link);
+		$self->load_page(
+			$self->{page}->resolve_link($link) );
 	}
 }
 
@@ -506,7 +565,7 @@ or a page object.
 =cut
 
 sub load_page {
-	my ($self, $page) = @_;
+	my ($self, $page, @args) = @_;
 	
 	if ($self->{page}) {
 		$self->{save_lock} = 0; # just to be sure
@@ -527,7 +586,7 @@ sub load_page {
 			unless length $page;
 		
 		my $p;
-		eval { $p = $self->{repository}->load_page($page) };
+		eval { $p = $self->{repository}->load_page($page, @args) };
 		return $self->error_dialog("Could not load page $page\n\n$@")
 			if $@;
 		
@@ -547,7 +606,7 @@ sub load_page {
 	}
 	$rec = $self->{objects}{History}->record($page) unless defined $rec;
 	$self->{objects}{PageView}->set_state(%$rec) if defined $rec;
-	$self->signal_emit('page_loaded', $self->{page}->realname);
+	$self->signal_emit('page_loaded', $self->{page}->name);
 	
 	$self->{window}->set_title($self->{page}->name.' - Zim');
 	$self->update_status();
@@ -586,17 +645,17 @@ sub save_page {
 		my $old_status = $page->status;
 		if (@$tree > 2) { # content
 			$self->{repository}->save_page($page);
-			$self->signal_emit('page_created', $page->realname)
+			$self->signal_emit('page_created', $page->name)
 				if $old_status eq 'new' or $old_status eq 'deleted';
 		}
 		else {
 			$self->{repository}->delete_page($page);
-			$self->signal_emit('page_deleted', $page->realname);
+			$self->signal_emit('page_deleted', $page->name);
 		}
 	};
 	unless ($@) {
 		$self->{objects}{PageView}->modified(0);
-		$self->signal_emit('page_saved', $page->realname);
+		$self->signal_emit('page_saved', $page->name);
 		$self->update_status();
 	}
 	else { # FIXME this dialog could be a lot better
@@ -625,9 +684,9 @@ shown to ask for a page name.
 sub move_page {
 	my ($self, $from, $to) = @_;
 
-	$from = $self->{page}->realname unless defined $from;
+	$from = $self->{page}->name unless defined $from;
 	
-	my $move_current = ($from eq $self->{page}->realname);
+	my $move_current = ($from eq $self->{page}->name);
 	if ($move_current) { # FIXME clearer interface for this
 		$self->{save_lock} = 0 if $move_current;
 		$self->save_page or return;
@@ -662,16 +721,14 @@ If PAGE is undefined the current page is deleted.
 =cut
 
 sub delete_page {
-	# FIXME no option to delete a whole namespace so far
-	# although probably what you wnat, this is not consistent
-	# with move_page()
+	# FIXME option to delete a complete sub-tree
 	# FIXME integrate with the save_page() logic, now we have 
 	# redundant code here
 	my ($self, $page) = @_;
-	$page = $self->{page}->realname unless defined $page;
+	$page = $self->{page}->name unless defined $page;
 	
-	my $name = ref($page) ? $page->realname : $page;
-	my $delete_current = ($name eq $self->{page}->realname);
+	my $name = ref($page) ? $page->name : $page;
+	my $delete_current = ($name eq $self->{page}->name);
 	$self->save_page; # Mind you, overriding save lock could lock us here
 	
 	return unless $self->prompt_confirm_delete_page($name);
@@ -680,7 +737,11 @@ sub delete_page {
 	eval { $self->{repository}->delete_page($page) };
 	return $self->error_dialog("Could not delete $name\n\n$@") if $@;
 
-	$self->signal_emit('page_deleted', $name);
+	# TODO trigger this with signals
+	# problem is that we might have deleted a whole namespace
+	$self->{objects}{TreeView}->{_loaded} = 0;
+	$self->{objects}{TreeView}->load_index;
+
 	if ($delete_current) {
 		eval { $self->{objects}{PageView}->load_page($page) };
 		if ($@) {
@@ -720,7 +781,7 @@ information.
 
 sub update_status {
 	my $self = shift;
-	my $stat = ' '.$self->{page}->realname;
+	my $stat = ' '.$self->{page}->name;
 	if ($_ = $self->{page}->status()) { $stat .= ' ('.uc($_).')' }
 	$stat .= $self->{objects}{PageView}->get_status;
 	$self->push_status($stat, 'page');
@@ -806,8 +867,9 @@ sub add_key {
 	my ($self, $key, $code) = @_;
 	
 	my $mod = [];
-	if    ($key =~ s/^alt //i)  { $mod = 'mod1-mask'    }
-	elsif ($key =~ s/^ctrl //i) { $mod = 'control-mask' }
+	push @$mod, 'control-mask' if $key =~ s/^ctrl //i;
+	push @$mod, 'mod1-mask'    if $key =~ s/^alt //i;
+	push @$mod, 'shift-mask'   if $key =~ s/^shift //i;
 	$key = $Gtk2::Gdk::Keysyms{$key} || ord($key);
 
 	$self->{accels}->connect($key, $mod, 'visible', $code);
@@ -902,6 +964,27 @@ sub error_dialog {
 	$dialog->destroy;
 }
 
+=item C<repository_lock_dialog>
+
+=cut
+
+sub repository_lock_dialog {
+	my $self = shift;
+	my $dir = shift;
+	my $dialog = Gtk2::MessageDialog->new(
+		$self->{window}, 'modal', 'warning', 'yes-no', << "EOT");
+The directory $dir 
+seems to be already in use by
+an other instance of zim.
+
+Are you sure you want to continue ?
+EOT
+	$dialog->set_default_response('no');
+	my $ok = ($dialog->run eq 'yes') ? 1 : 0;
+	$dialog->destroy;
+	return $ok;
+}
+
 =item C<goto_page_dialog()>
 
 Prompts the user for a page name. This page is then opened.
@@ -915,7 +998,7 @@ sub goto_page_dialog {
 	$self->link_clicked($page) if defined $page;
 }
 
-=item C<promt_page_dialog(PAGE, TITLE, PROMPT, TEXT, ICON)>
+=item C<prompt_page_dialog(PAGE, TITLE, PROMPT, TEXT, ICON)>
 
 Method used to prompt the user for a page name. Returns PAGE.
 
@@ -972,6 +1055,10 @@ sub prompt_page_dialog {
 	return $page;
 }
 
+=item C<prompt_move_page_dialog>
+
+=cut
+
 sub prompt_move_page_dialog {
 	my ($self, $page) = @_;
 	
@@ -1176,6 +1263,7 @@ sub filechooser_dialog {
 		$dialog = Gtk2::FileSelection->new($title);
 	}
 	$dialog->set_icon($self->{window}->get_icon) if $self->{window};
+	$dialog->set_action('select-folder');
 	$dialog->set_filename(File::Spec->rel2abs($file)) if defined $file;
 	$dialog->signal_connect('response', sub {
 		$file = $_[1] eq 'ok' ? $dialog->get_filename : undef;
@@ -1186,6 +1274,10 @@ sub filechooser_dialog {
 	return $file;
 }
 
+=item C<prompt_root_dialog>
+
+=cut
+
 sub prompt_root_dialog {
 	my ($self, $page, $title, $prompt, $text, $icon) = @_;
 
@@ -1240,6 +1332,45 @@ EOT
 	return $root;
 }
 
+=item C<prompt_browser_dialog>
+
+=cut
+
+sub prompt_browser_dialog {
+	my $self = shift;
+	
+	my $title = "Choose browser";
+	my $dialog = Gtk2::Dialog->new(
+		$title, $self->{window},
+	       	[qw/modal destroy-with-parent no-separator/],
+		'gtk-ok'     => 'ok',
+		'gtk-cancel' => 'cancel',
+	);
+	$dialog->set_resizable(0);
+	$dialog->set_border_width(5);
+	$dialog->set_icon($self->{window}->get_icon);
+	$dialog->set_default_response('ok');
+
+	my $label = Gtk2::Label->new(<< "EOT");
+Please enter a browser
+to open external links.
+EOT
+	$dialog->vbox->add($label);
+	
+	my $entry = Gtk2::Entry->new();
+	$entry->signal_connect(activate => sub { $dialog->response('ok') });
+	$entry->set_text("firefox '\%s'");
+	$dialog->vbox->add($entry);
+
+	$dialog->show_all;
+	my $browser = 
+		($dialog->run eq 'ok') ? $entry->get_text : undef ;
+	$dialog->destroy;
+	$browser = undef unless $browser =~ /\S/;
+
+	return $browser;
+}
+
 # "Search" dialog
 #
 # This dialog asks for a search query and then generates
