@@ -5,7 +5,7 @@ use vars '$AUTOLOAD';
 use Gtk2;
 use Gtk2::Gdk::Keysyms;
 
-our $VERSION = 0.01;
+our $VERSION = 0.08;
 
 =head1 NAME
 
@@ -22,6 +22,14 @@ Undefined methods AUTOLOAD to the L<Gtk2::TreeView> widget.
 
 =over 4
 
+=item C<new(app => PARENT)>
+
+Simple constructor.
+
+=item C<init()>
+
+Method called by the constructor.
+
 =cut
 
 my ($k_left, $k_right) = @Gtk2::Gdk::Keysyms{qw/Left Right/};
@@ -66,15 +74,15 @@ sub init { # called by new()
 	$scroll_window->add($tree_view);
 	$self->{tree_view} = $tree_view;
 
-	my @buttons;
-	push @buttons, $self->{app}->add_button(
-        	'Expand All', 'Ctrl +', 'gtk-zoom-in', sub {$tree_view->expand_all});
-	$self->{app}->add_key('Ctrl KP_Add', sub {$tree_view->expand_all});
-	$self->{app}->add_key('Ctrl =', sub {$tree_view->expand_all});
-	push @buttons, $self->{app}->add_button(
-		'Collapse All', 'Ctrl -', 'gtk-zoom-out', sub {$tree_view->collapse_all});
-	$self->{app}->add_key('Ctrl KP_Subtract', sub {$tree_view->collapse_all});
-	$self->{buttons} = \@buttons;
+#	my @buttons;
+#	push @buttons, $self->{app}->add_button(
+#        	'Expand All', 'Ctrl +', 'gtk-zoom-in', sub {$tree_view->expand_all});
+#	$self->{app}->add_key('Ctrl KP_Add', sub {$tree_view->expand_all});
+#	$self->{app}->add_key('Ctrl =', sub {$tree_view->expand_all});
+#	push @buttons, $self->{app}->add_button(
+#		'Collapse All', 'Ctrl -', 'gtk-zoom-out', sub {$tree_view->collapse_all});
+#	$self->{app}->add_key('Ctrl KP_Subtract', sub {$tree_view->collapse_all});
+#	$self->{buttons} = \@buttons;
 	
 	$self->{app}->signal_connect(page_loaded => sub {$self->select_page(pop)});
 	$self->{app}->signal_connect(page_deleted => sub {$self->unlist_page(pop)});
@@ -162,7 +170,7 @@ sub on_row_activated { # load a page when clicked or entered
 	my ($tree_view, $path) = @_;
 	my $page = $self->page_from_path($path);
 	$self->{app}->load_page($page)
-		unless $page eq $self->{app}{page}->realname;
+		unless $page eq $self->{app}{page}->name;
 }
 
 =item C<page_from_path(PATH)>
@@ -175,8 +183,8 @@ sub page_from_path {
 	my ($self, $path) = @_;
 	my $model = $self->{tree_view}->get_model;
 	my $iter = $model->get_iter($path);
-	my ($base, $real) = $model->get($iter);
-	return wantarray ? ($real, $base) : $real;
+	my ($basename, $name) = $model->get($iter);
+	return wantarray ? ($name, $basename) : $name;
 }
 
 =item C<activate_if_selected(PATH, COLUMN)>
@@ -198,7 +206,7 @@ sub activate_if_selected { # single-click navigation
 	my $page = $self->page_from_path($path);
 	$column ||= $tree_view->get_column(0);
 	$tree_view->row_activated($path, $column)
-		unless $page eq $self->{app}{page}->realname;
+		unless $page eq $self->{app}{page}->name;
 }
 
 =item C<popup_context_menu(PATH, EVENT)>
@@ -234,11 +242,13 @@ sub popup_context_menu {
 	return 1; # needed for popup_menu signal (shift-F10), but why ?
 }
 
-# load_index()
-#
-# Called the first time the pane is showed to fill the index tree.
-#
-# TODO this should be caching algo
+=item C<load_index()>
+
+Called the first time the pane is showed to fill the index tree.
+
+Will be DEPRECATED.
+
+=cut
 
 sub load_index {
 	my $self = shift;
@@ -246,14 +256,16 @@ sub load_index {
 	$self->{tree_store}->clear; # just to be sure
 	$self->{tree_iter} = {};
 	eval { $self->list_pages('') };
-	$self->select_page($self->{app}{page}->realname);
+	$self->select_page($self->{app}{page}->name);
 	$self->{app}->message("Index loaded");
 	$self->{_loaded} = 1;
 }
 
-# list_pages(namespace)
-#
-# Wrapper around Zim->list_pages that fills the index tree.
+=item C<list_pages(NAMESPACE)>
+
+Wrapper around C<Zim->list_pages> that fills the index tree.
+
+=cut
 
 sub list_pages {
 	my ($self, $namespace) = @_;
@@ -267,9 +279,11 @@ sub list_pages {
 	Gtk2->main_iteration while (Gtk2->events_pending);
 }
 
-# list_page(realname)
-#
-# Adds a page to the index tree.
+=item C<list_page(REALNAME)>
+
+Adds a page to the index tree.
+
+=cut
 
 sub list_page {
 	my ($self, $name) = @_;
@@ -294,9 +308,11 @@ sub list_page {
 	return 1;
 }
 
-# unlist_page(realname)
-#
-# Removes a page from the index unless it has children.
+=item C<unlist_page(REALNAME)>
+
+Removes a page from the index unless it has children.
+
+=cut
 
 sub unlist_page {
 	my ($self, $page) = @_;
