@@ -2,7 +2,7 @@ package Zim::Formats::Html;
 
 use strict;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 =head1 NAME
 
@@ -26,20 +26,25 @@ Converts a parse tree into plain text.
 
 =cut
 
-sub extension { 'html' }
+# WARNING: the api for exporting is not yet stable
+#          do not use this as a reference implementation .. yet
+
+# TODO avoid reading the template for ech page, cache it somewhere
+
+sub _extension { 'html' }
 
 sub save_tree {
 	my ($class, $tree, $page) = @_;
 
-	my $text = dump_node($tree, $page);
+	my $text = _dump_node($tree, $page);
 	
-	my $template = $page->{zim}{template};
+	my $template = $page->{repository}{_template};
 	$template = _read_file($template);
 	$template =~ s/\%\%CONTENT\%\%/$text/;
 	return $template;
 }
 
-sub dump_node {
+sub _dump_node {
 	my ($node, $page) = @_;
 	my ($name, $opt) = splice @$node, 0, 2;
 	
@@ -55,11 +60,11 @@ sub dump_node {
 	elsif ($name eq 'Verbatim') {
 		@tags = ("<blockquote>\n<pre>\n", "</pre>\n</blockquote>\n")
 	}
-	elsif ($name eq 'B') { @tags = ('<b>', '</b>') }
-	elsif ($name eq 'I') { @tags = ('<i>', '</i>') }
-	elsif ($name eq 'U') { @tags = ('<u>', '</u>') }
-	elsif ($name eq 'C') { @tags = ('<tt>', '</tt>') }
-	elsif ($name eq 'L') {
+	elsif ($name eq 'bold'     ) { @tags = ('<b>', '</b>')   }
+	elsif ($name eq 'italic'   ) { @tags = ('<i>', '</i>')   }
+	elsif ($name eq 'underline') { @tags = ('<u>', '</u>')   }
+	elsif ($name eq 'verbatim' ) { @tags = ('<tt>', '</tt>') }
+	elsif ($name eq 'link') {
 		my $href = $$opt{to};
 		unless ($href =~ m#^(\w+://|mailto:)#) {
 			$href = $page->resolve_link($$opt{to});
@@ -74,7 +79,7 @@ sub dump_node {
 	}	
 
 	for (@$node) {
-		if (ref $_) { $text .= dump_node($_, $page) } # recurse
+		if (ref $_) { $text .= _dump_node($_, $page) } # recurse
 		else {
 			$_ =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/'&#'.(ord($1)).';'/eg; # RegEx copy pasted from Pod::Simple::Html
 			$text .= $_;
@@ -88,7 +93,7 @@ sub parse_list { # FIXME totally wrong level for this kind of parsing :(
 	
 	my ($text, $level, $close);
 	for (@nodes) {
-		if (ref $_) { $text .= dump_node($_, $page) }
+		if (ref $_) { $text .= _dump_node($_, $page) }
 		else {
 			$_ =~ s/([^-\n\t !\#\$\%\(\)\*\+,\.\~\/\:\;=\?\@\[\\\]\^_\`\{\|\}abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789])/'&#'.(ord($1)).';'/eg; # RegEx copy pasted from Pod::Simple::Html
 			my @lines = split /[\n\r]+/, $_;
