@@ -3,7 +3,11 @@ package Zim::Formats::Wiki;
 use strict;
 no warnings;
 
-our $VERSION = 0.06;
+our $VERSION = 0.08;
+
+# TODO: some tags can be nested: email links for example
+# TODO: header in the middle of a para doesn't get recognized
+
 
 =head1 NAME
 
@@ -35,7 +39,7 @@ Returns the parse tree.
 
 =cut
 
-sub extension { return 'txt' }
+sub _extension { return 'txt' }
 
 sub load_tree {
 	# split in headers and paragraphs
@@ -108,7 +112,7 @@ sub parse_link { # parse links and urls
 				$_ = "mailto:$_";
 			}
 			
-			['L', {to => $_}, length($text) ? $text : $_ ]
+			['link', {to => $_}, length($text) ? $text : $_ ]
 		} else { $_ }
 	} split /(
 		\[\[.+?\]\]                |
@@ -122,10 +126,10 @@ sub parse_styles { # parse blocks of bold, italic and underline
 	my $i = 0;
 	return	map {
 		unless ($i++ % 2) { $_ }
-		elsif (/^\'\'(.+)\'\'$/) { ['C', {}, $1] }
-		elsif (/^\*\*(.+)\*\*$/) { ['B', {}, $1] }
-		elsif (/^\/\/(.+)\/\/$/) { ['I', {}, $1] }
-		elsif (/^\_\_(.+)\_\_$/) { ['U', {}, $1] }
+		elsif (/^\'\'(.+)\'\'$/) { ['verbatim',  {}, $1] }
+		elsif (/^\*\*(.+)\*\*$/) { ['bold',      {}, $1] }
+		elsif (/^\/\/(.+)\/\/$/) { ['italic',    {}, $1] }
+		elsif (/^\_\_(.+)\_\_$/) { ['underline', {}, $1] }
 	} split /(?<!\S)(
 		\'\'.+?\'\' |
 		\*\*.+?\*\* |
@@ -170,17 +174,17 @@ sub save_tree { ## unknown tags just fall through as plain text
 		elsif ($tag eq 'image') {
 			$text .= '{{'.$$meta{src}.'}}';
 		}
-		elsif ($tag eq 'L') {
+		elsif ($tag eq 'link') {
 			my $to = $$meta{to};
 			$to =~ s/^mailto://;
 			if ($to ne $node[0]) { $text .= "[[$to|$node[0]]]" }
 			elsif ($to =~ m#^\w+://#) { $text .= $to }
 			else { $text .= "[[$to]]" }
 		}
-		elsif ($tag eq 'B') { $text .= "**$node[0]**"  }
-		elsif ($tag eq 'I') { $text .= "//$node[0]//"  }
-		elsif ($tag eq 'U') { $text .= "__$node[0]\__" }
-		elsif ($tag eq 'C') { $text .= "''$node[0]''"  }
+		elsif ($tag eq 'bold')      { $text .= "**$node[0]**"  }
+		elsif ($tag eq 'italic')    { $text .= "//$node[0]//"  }
+		elsif ($tag eq 'underline') { $text .= "__$node[0]\__" }
+		elsif ($tag eq 'verbatim')  { $text .= "''$node[0]''"  }
 	}
 	$text =~ s/\n?$/\n/; # unix files should always end with \n
 	return $text;
